package Translate::Fluent::Elements::DefaultVariant;

use Moo;
extends 'Translate::Fluent::Elements::Variant';

1;

__END__

=head1 NOTHING TO SEE HERE

This file is part of L<Translate::Fluent>. See its documentation for more
information.

=cut

